@@ -35,11 +35,13 @@ def get_board_items_first_page_query(
       }
         boards(ids: %s){
             name
+            updated_at
             items_page %s {
                 cursor
                 items {
                     id
                     name
+                    updated_at
                     group {
                         id
                         title
@@ -65,6 +67,7 @@ def get_board_items_first_page_query(
                     subitems {
                       name
                       id
+                      updated_at
                       parent_item {
                         id
                       }
@@ -112,6 +115,7 @@ def get_board_items_pagination_query(cursor: str, limit: int) -> str:
             items {
                 id
                 name
+                updated_at
                 group {
                     id
                     title
@@ -137,6 +141,7 @@ def get_board_items_pagination_query(cursor: str, limit: int) -> str:
                 subitems {
                   name
                   id
+                  updated_at
                   group {
                     id
                     title
@@ -544,11 +549,19 @@ def get_updates_for_item_query(item_id, limit: int):
     return query
 
 
-def get_updates_for_board(board_id, limit: int, page=1):
+def get_updates_for_board(board_id, limit: int, page=1, from_date: Optional[str] = None, to_date: Optional[str] = None):
+    # Build the updates parameters
+    updates_params = f"limit: {limit}, page: {page}"
+    
+    if from_date:
+        updates_params += f', from_date: "{from_date}"'
+    if to_date:
+        updates_params += f', to_date: "{to_date}"'
+    
     query = """query
     {
         boards(ids: %s) {
-            updates(limit: %s, page: %s) {
+            updates(%s) {
                 id,
                 text_body,
                 item_id,
@@ -562,8 +575,7 @@ def get_updates_for_board(board_id, limit: int, page=1):
         }
     }""" % (
         board_id,
-        limit,
-        page,
+        updates_params,
     )
 
     return query
@@ -763,6 +775,7 @@ def get_docs_query(object_id: str, page: int = 1) -> str:
         docs (object_ids: %s) {
             id
             created_at
+            updated_at
             created_by {
                 id
                 name
