@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import Optional, List
+from typing import Optional, List, Dict, Any
 
 
 @dataclass
@@ -66,6 +66,7 @@ class DocumentBlock:
 class Document:
     id: Optional[str] = field(default=None)
     created_at: Optional[str] = field(default=None)
+    updated_at: Optional[str] = field(default=None)
     created_by: Optional[User] = field(default=None)
     doc_folder_id: Optional[str] = field(default=None)
     doc_kind: Optional[str] = field(default=None)
@@ -115,6 +116,7 @@ class ActivityLog:
 class Board:
     id: Optional[str] = field(default=None)
     name: Optional[str] = field(default=None)
+    updated_at: Optional[str] = field(default=None)
     items_page: Optional[ItemsPage] = field(default=None)
     updates: Optional[List[Update]] = field(default_factory=list)
     activity_logs: Optional[List[ActivityLog]] = field(default_factory=list)
@@ -136,4 +138,5 @@ class Data:
 @dataclass
 class MondayApiResponse:
     data: Data
-    account_id: Optional[int] = field(default=None)
\ No newline at end of file
+    account_id: Optional[int] = field(default=None)
+    response_data: Optional[Dict[str, Any]] = field(default=None)
